@@ -103,6 +103,13 @@ def run_demo(home):
 2. Hit Control-C to stop the server.
 3. Re-start the server by running "roundup-demo" again.
 4. Re-initialise the server by running "roundup-demo nuke".
+
+Demo tracker is set up to be accessed by localhost browser.  If you
+run demo on a server host, please stop the demo, open file
+"demo/config.ini" with your editor, change the host name in the "web"
+option in section "[tracker]", save the file, then re-run the demo
+program.
+
 ''' % url
 
     # disable command line processing in roundup_server
