@@ -67,6 +67,11 @@ class RequestWrapper:
     def end_headers(self):
         # not needed - the RESPONSE object handles this internally on write()
         pass
+    def start_response(self, headers, response):
+        self.send_response(response)
+        for key, value in headers:
+            self.send_header(key, value)
+        self.end_headers()
 
 class FormItem:
     '''Make a Zope form item look like a cgi.py one
@@ -89,6 +94,8 @@ class FormWrapper:
         else:
             entry = FormItem(entry)
         return entry
+    def __iter__(self):
+        return iter(self.__form)
     def getvalue(self, key, default=None):
         if self.__form.has_key(key):
             return self.__form[key]
