@@ -144,6 +144,9 @@ class Database(rdbms_common.Database):
         self.sql('CREATE TABLE __words (_word varchar, '
             '_textid integer)')
         self.sql('CREATE INDEX words_word_ids ON __words(_word)')
+        self.sql('CREATE INDEX words_by_id ON __words (_textid)')
+        self.sql('CREATE UNIQUE INDEX __textids_by_props ON '
+                 '__textids (_class, _itemid, _prop)')
         sql = 'insert into ids (name, num) values (%s,%s)'%(self.arg, self.arg)
         self.sql(sql, ('__textids', 1))
 
