@@ -3,7 +3,7 @@
 is a mapping of words to occurance IDs. The second maps the IDs to (Class,
 propname, itemid) instances.
 '''
-import re
+import re, sets
 
 from roundup.backends.indexer_common import Indexer as IndexerBase
 
@@ -45,38 +45,31 @@ class Indexer(IndexerBase):
         self.db.cursor.execute(sql, identifier)
         r = self.db.cursor.fetchone()
         if not r:
+            # not previously indexed
             id = self.db.newid('__textids')
             sql = 'insert into __textids (_textid, _class, _itemid, _prop)'\
                 ' values (%s, %s, %s, %s)'%(a, a, a, a)
             self.db.cursor.execute(sql, (id, ) + identifier)
-            self.db.cursor.execute('select max(_textid) from __textids')
-            id = self.db.cursor.fetchone()[0]
         else:
             id = int(r[0])
             # clear out any existing indexed values
             sql = 'delete from __words where _textid=%s'%a
             self.db.cursor.execute(sql, (id, ))
 
-        # ok, find all the words in the text
+        # ok, find all the unique words in the text
         text = unicode(text, "utf-8", "replace").upper()
         wordlist = [w.encode("utf-8", "replace")
                 for w in re.findall(r'(?u)\b\w{2,25}\b', text)]
-        words = {}
+        words = sets.Set()
         for word in wordlist:
             if self.is_stopword(word): continue
             if len(word) > 25: continue
-            words[word] = 1
-        words = words.keys()
+            words.add(word)
 
         # for each word, add an entry in the db
-        for word in words:
-            # don't dupe
-            sql = 'select * from __words where _word=%s and _textid=%s'%(a, a)
-            self.db.cursor.execute(sql, (word, id))
-            if self.db.cursor.fetchall():
-                continue
-            sql = 'insert into __words (_word, _textid) values (%s, %s)'%(a, a)
-            self.db.cursor.execute(sql, (word, id))
+        sql = 'insert into __words (_word, _textid) values (%s, %s)'%(a, a)
+        words = [(word, id) for word in words]
+        self.db.cursor.executemany(sql, words)
 
     def find(self, wordlist):
         '''look up all the words in the wordlist.
@@ -102,7 +95,7 @@ class Indexer(IndexerBase):
             a = ','.join([self.db.arg] * len(r))
             sql = 'select _class, _itemid, _prop from __textids '\
                 'where _textid in (%s)'%a
-            self.db.cursor.execute(sql, tuple([int(id) for (id,) in r]))
+            self.db.cursor.execute(sql, tuple([int(row[0]) for row in r]))
 
         else:
             # A more complex version for MySQL since it doesn't implement INTERSECT
