@@ -8,6 +8,8 @@ class. It's now also used for One Time Key handling too.
 __docformat__ = 'restructuredtext'
 
 import anydbm, whichdb, os, marshal, time
+from roundup import hyperdb
+from roundup.i18n import _
 
 class BasicDatabase:
     ''' Provide a nice encapsulation of an anydbm store.
@@ -44,7 +46,8 @@ class BasicDatabase:
         if os.path.exists(path):
             db_type = whichdb.whichdb(path)
             if not db_type:
-                raise hyperdb.DatabaseError, "Couldn't identify database type"
+                raise hyperdb.DatabaseError, \
+                    _("Couldn't identify database type")
         elif os.path.exists(path+'.db'):
             # if the path ends in '.db', it's a dbm database, whether
             # anydbm says it's dbhash or not!
@@ -155,3 +158,4 @@ class Sessions(BasicDatabase):
 class OneTimeKeys(BasicDatabase):
     name = 'otks'
 
+# vim: set sts ts=4 sw=4 et si :
