@@ -77,7 +77,7 @@ class BasicDatabase:
             self.name, self.db.arg), (infoid,))
 
     def updateTimestamp(self, infoid):
-        ''' don't update every hit - once a minute should be OK '''
+        """ don't update every hit - once a minute should be OK """
         now = time.time()
         self.cursor.execute('''update %ss set %s_time=%s where %s_key=%s
             and %s_time < %s'''%(self.name, self.name, self.db.arg,
@@ -97,3 +97,4 @@ class Sessions(BasicDatabase):
 class OneTimeKeys(BasicDatabase):
     name = 'otk'
 
+# vim: set et sts=4 sw=4 :
