@@ -35,6 +35,8 @@ class TranslationServiceMixin:
         return _msg
 
     def gettext(self, msgid):
+        if not isinstance(msgid, unicode):
+            msgid = unicode(msgid, 'utf8')
         return self.ugettext(msgid).encode(self.OUTPUT_ENCODING)
 
     def ngettext(self, singular, plural, number):
