@@ -148,7 +148,7 @@ class SearchAction(Action):
         """
         self.fakeFilterVars()
         queryname = self.getQueryName()
-    
+
         # editing existing query name?
         old_queryname = self.getFromForm('old-queryname')
 
@@ -367,9 +367,11 @@ class EditCommon(Action):
         deps = {}
         links = {}
         for cn, nodeid, propname, vlist in all_links:
-            if not all_props.has_key((cn, nodeid)):
+            numeric_id = int (nodeid or 0)
+            if not (numeric_id > 0 or all_props.has_key((cn, nodeid))):
                 # link item to link to doesn't (and won't) exist
                 continue
+
             for value in vlist:
                 if not all_props.has_key(value):
                     # link item to link to doesn't (and won't) exist
@@ -401,36 +403,33 @@ class EditCommon(Action):
         m = []
         for needed in order:
             props = all_props[needed]
-            if not props:
-                # nothing to do
-                continue
             cn, nodeid = needed
+            if props:
+                if nodeid is not None and int(nodeid) > 0:
+                    # make changes to the node
+                    props = self._changenode(cn, nodeid, props)
 
-            if nodeid is not None and int(nodeid) > 0:
-                # make changes to the node
-                props = self._changenode(cn, nodeid, props)
-
-                # and some nice feedback for the user
-                if props:
-                    info = ', '.join(map(self._, props.keys()))
-                    m.append(
-                        self._('%(class)s %(id)s %(properties)s edited ok')
-                        % {'class':cn, 'id':nodeid, 'properties':info})
+                    # and some nice feedback for the user
+                    if props:
+                        info = ', '.join(map(self._, props.keys()))
+                        m.append(
+                            self._('%(class)s %(id)s %(properties)s edited ok')
+                            % {'class':cn, 'id':nodeid, 'properties':info})
+                    else:
+                        m.append(self._('%(class)s %(id)s - nothing changed')
+                            % {'class':cn, 'id':nodeid})
                 else:
-                    m.append(self._('%(class)s %(id)s - nothing changed')
-                        % {'class':cn, 'id':nodeid})
-            else:
-                assert props
+                    assert props
 
-                # make a new node
-                newid = self._createnode(cn, props)
-                if nodeid is None:
-                    self.nodeid = newid
-                nodeid = newid
+                    # make a new node
+                    newid = self._createnode(cn, props)
+                    if nodeid is None:
+                        self.nodeid = newid
+                    nodeid = newid
 
-                # and some nice feedback for the user
-                m.append(self._('%(class)s %(id)s created')
-                    % {'class':cn, 'id':newid})
+                    # and some nice feedback for the user
+                    m.append(self._('%(class)s %(id)s created')
+                        % {'class':cn, 'id':newid})
 
             # fill in new ids in links
             if links.has_key(needed):
@@ -772,7 +771,7 @@ class ConfRegoAction(RegoCommon):
         except (ValueError, KeyError), message:
             self.client.error_message.append(str(message))
             return
-        self.finishRego()
+        return self.finishRego()
 
 class RegisterAction(RegoCommon, EditCommon):
     name = 'register'
