@@ -22,12 +22,13 @@
 __docformat__ = 'restructuredtext'
 
 # standard python modules
-import sys, os, time, re, shutil, weakref
+import os, re, shutil, weakref
 from sets import Set
 
 # roundup modules
 import date, password
 from support import ensureParentsExist, PrioList, sorted, reversed
+from roundup.i18n import _
 
 #
 # Types
@@ -73,15 +74,17 @@ class Password(_Type):
             p = password.Password()
             p.scheme = m.group(1)
             if p.scheme not in 'SHA crypt plaintext'.split():
-                raise HyperdbValueError, 'property %s: unknown encryption '\
-                    'scheme %r'%(kw['propname'], p.scheme)
+                raise HyperdbValueError, \
+                        ('property %s: unknown encryption scheme %r') %\
+                        (kw['propname'], p.scheme)
             p.password = m.group(2)
             value = p
         else:
             try:
                 value = password.Password(value)
             except password.PasswordValueError, message:
-                raise HyperdbValueError, 'property %s: %s'%(propname, message)
+                raise HyperdbValueError, \
+                        _('property %s: %s')%(kw['propname'], message)
         return value
     def sort_repr (self, cls, val, name):
         if not val:
@@ -101,8 +104,8 @@ class Date(_Type):
         try:
             value = date.Date(value, self.offset(db))
         except ValueError, message:
-            raise HyperdbValueError, 'property %s: %r is an invalid '\
-                'date (%s)'%(kw['propname'], value, message)
+            raise HyperdbValueError, _('property %s: %r is an invalid '\
+                'date (%s)')%(kw['propname'], value, message)
         return value
     def range_from_raw(self, value, db):
         """return Range value from given raw value with offset correction"""
@@ -118,8 +121,8 @@ class Interval(_Type):
         try:
             value = date.Interval(value)
         except ValueError, message:
-            raise HyperdbValueError, 'property %s: %r is an invalid '\
-                'date interval (%s)'%(kw['propname'], value, message)
+            raise HyperdbValueError, _('property %s: %r is an invalid '\
+                'date interval (%s)')%(kw['propname'], value, message)
         return value
     def sort_repr (self, cls, val, name):
         if not val:
@@ -213,8 +216,8 @@ class Multilink(_Pointer):
                 try:
                     curvalue.remove(itemid)
                 except ValueError:
-                    raise HyperdbValueError, 'property %s: %r is not ' \
-                        'currently an element'%(propname, item)
+                    raise HyperdbValueError, _('property %s: %r is not ' \
+                        'currently an element')%(propname, item)
             else:
                 newvalue.append(itemid)
                 if itemid not in curvalue:
@@ -257,7 +260,7 @@ class Number(_Type):
         try:
             value = float(value)
         except ValueError:
-            raise HyperdbValueError, 'property %s: %r is not a number'%(
+            raise HyperdbValueError, _('property %s: %r is not a number')%(
                 kw['propname'], value)
         return value
 #
@@ -270,7 +273,7 @@ def splitDesignator(designator, dre=re.compile(r'([^\d]+)(\d+)')):
     '''
     m = dre.match(designator)
     if m is None:
-        raise DesignatorError, '"%s" not a node designator'%designator
+        raise DesignatorError, _('"%s" not a node designator')%designator
     return m.group(1), m.group(2)
 
 class Proptree(object):
@@ -487,7 +490,7 @@ class Proptree(object):
         else:
             self._val = val
         self.has_values = True
-    
+
     val = property(lambda self: self._val, _set_val)
 
     def _sort(self, val):
@@ -943,7 +946,7 @@ class Class:
            resolution order.
         """
         if labelprop not in self.getprops():
-            raise ValueError, "Not a property name: %s" % labelprop
+            raise ValueError, _("Not a property name: %s") % labelprop
         self._labelprop = labelprop
 
     def setorderprop(self, orderprop):
@@ -951,7 +954,7 @@ class Class:
            resolution order
         """
         if orderprop not in self.getprops():
-            raise ValueError, "Not a property name: %s" % orderprop
+            raise ValueError, _("Not a property name: %s") % orderprop
         self._orderprop = orderprop
 
     def getkey(self):
@@ -1136,7 +1139,7 @@ class Class:
         for all issues where a message was added by a certain user in
         the last week with a filterspec of
         {'messages.author' : '42', 'messages.creation' : '.-1w;'}
-        
+
         Implementation note:
         This implements a non-optimized version of Transitive search
         using _filter implemented in a backend class. A more efficient
@@ -1234,11 +1237,11 @@ def convertLinkValue(db, propname, prop, value, idre=re.compile('^\d+$')):
             try:
                 value = linkcl.lookup(value)
             except KeyError, message:
-                raise HyperdbValueError, 'property %s: %r is not a %s.'%(
+                raise HyperdbValueError, _('property %s: %r is not a %s.')%(
                     propname, value, prop.classname)
         else:
-            raise HyperdbValueError, 'you may only enter ID values '\
-                'for property %s'%propname
+            raise HyperdbValueError, _('you may only enter ID values '\
+                'for property %s')%propname
     return value
 
 def fixNewlines(text):
@@ -1267,7 +1270,7 @@ def rawToHyperdb(db, klass, itemid, propname, value, **kw):
     try:
         proptype =  properties[propname]
     except KeyError:
-        raise HyperdbValueError, '%r is not a property of %s'%(propname,
+        raise HyperdbValueError, _('%r is not a property of %s')%(propname,
             klass.classname)
 
     # if we got a string, strip it now
@@ -1291,7 +1294,7 @@ class FileClass:
         property.
         '''
         if not properties.has_key('content'):
-            properties['content'] = hyperdb.String(indexme='yes')
+            properties['content'] = String(indexme='yes')
 
     def export_propnames(self):
         ''' Don't export the "content" property
@@ -1390,6 +1393,6 @@ def Choice(name, db, *options):
     cl = Class(db, name, name=String(), order=String())
     for i in range(len(options)):
         cl.create(name=options[i], order=i)
-    return hyperdb.Link(name)
+    return Link(name)
 
 # vim: set filetype=python sts=4 sw=4 et si :
