@@ -55,13 +55,15 @@ def copytree(src, dst, symlinks=0):
         else:
             install_util.copyDigestedFile(srcname, dstname)
 
-def install(instance_home, template):
+def install(instance_home, template, settings={}):
     '''Install an instance using the named template and backend.
 
     'instance_home'
        the directory to place the instance data in
     'template'
        the directory holding the template to use in creating the instance data
+    'settings'
+       config.ini setting overrides (dictionary)
 
     The instance_home directory will be created using the files found in
     the named template (roundup.templates.<name>). A usual instance_home
@@ -99,7 +101,7 @@ def install(instance_home, template):
     # installed from the template, write default config text
     config_ini_file = os.path.join(instance_home, CoreConfig.INI_FILE)
     if not os.path.isfile(config_ini_file):
-        config = CoreConfig()
+        config = CoreConfig(settings=settings)
         config.save(config_ini_file)
 
 
