@@ -24,6 +24,7 @@ Backwards compatibility for the old-style "imported" trackers.
 __docformat__ = 'restructuredtext'
 
 import os
+import sys
 from roundup import configuration, mailgw
 from roundup import hyperdb, backends
 from roundup.cgi import client, templating
@@ -52,6 +53,9 @@ class Tracker:
         self.templates = templating.Templates(self.config["TEMPLATES"])
         self.backend = backends.get_backend(self.get_backend_name())
         if self.optimize:
+            libdir = os.path.join(self.tracker_home, 'lib')
+            if os.path.isdir(libdir):
+                sys.path.insert(1, libdir)
             self.templates.precompileTemplates()
             # initialize tracker extensions
             for extension in self.get_extensions('extensions'):
@@ -67,6 +71,8 @@ class Tracker:
             self.detectors = self.get_extensions('detectors')
             # db_open is set to True after first open()
             self.db_open = 0
+            if libdir in sys.path:
+                sys.path.remove(libdir)
 
     def get_backend_name(self):
         o = __builtins__['open']
@@ -102,12 +108,17 @@ class Tracker:
             # use preloaded detectors
             detectors = self.detectors
         else:
+            libdir = os.path.join(self.tracker_home, 'lib')
+            if os.path.isdir(libdir):
+                sys.path.insert(1, libdir)
             # execute the schema file
             self._load_python('schema.py', vars)
             # reload extensions and detectors
             for extension in self.get_extensions('extensions'):
                 extension(self)
             detectors = self.get_extensions('detectors')
+            if libdir in sys.path:
+                sys.path.remove(libdir)
         db = vars['db']
         # apply the detectors
         for detector in detectors:
@@ -142,12 +153,14 @@ class Tracker:
         extensions = []
         dirpath = os.path.join(self.tracker_home, dirname)
         if os.path.isdir(dirpath):
+            sys.path.insert(1, dirpath)
             for name in os.listdir(dirpath):
                 if not name.endswith('.py'):
                     continue
                 vars = {}
                 self._load_python(os.path.join(dirname, name), vars)
                 extensions.append(vars['init'])
+            sys.path.remove(dirpath)
         return extensions
 
     def init(self, adminpw):
