@@ -78,6 +78,10 @@ POP:
  are both valid. The username and/or password will be prompted for if
  not supplied on the command-line.
 
+POPS:
+ Connect to a POP server over ssl. This requires python 2.4 or later.
+ This supports the same notation as POP.
+
 APOP:
  Same as POP, but using Authenticated POP:
     apop username:password@server
@@ -154,12 +158,15 @@ def main(argv):
 
         if source == 'mailbox':
             return handler.do_mailbox(specification)
-        elif source == 'pop':
+        elif source == 'pop' or source == 'pops':
             m = re.match(r'((?P<user>[^:]+)(:(?P<pass>.+))?@)?(?P<server>.+)',
                 specification)
             if m:
+                ssl = source.endswith('s')
+                if ssl and sys.version_info<(2,4):
+                    return usage(argv, _('Error: a later version of python is required'))
                 return handler.do_pop(m.group('server'), m.group('user'),
-                    m.group('pass'))
+                    m.group('pass'),ssl)
             return usage(argv, _('Error: pop specification not valid'))
         elif source == 'apop':
             m = re.match(r'((?P<user>[^:]+)(:(?P<pass>.+))?@)?(?P<server>.+)',
@@ -172,9 +179,7 @@ def main(argv):
             m = re.match(r'((?P<user>[^:]+)(:(?P<pass>.+))?@)?(?P<server>.+)',
                 specification)
             if m:
-                ssl = 0
-                if source == 'imaps':
-                    ssl = 1
+                ssl = source.endswith('s')
                 mailbox = ''
                 if len(args) > 3:
                     mailbox = args[3]
