@@ -1188,11 +1188,21 @@ class DBTest(MyTestCase):
         ae(filt(None, {'deadline': '2002'}), [])
         ae(filt(None, {'deadline': '2003'}), ['1', '2', '3'])
         ae(filt(None, {'deadline': '2004'}), ['4'])
-        ae(filt(None, {'deadline': '2003-02'}), ['1', '3'])
-        ae(filt(None, {'deadline': '2003-03'}), [])
         ae(filt(None, {'deadline': '2003-02-16'}), ['1'])
         ae(filt(None, {'deadline': '2003-02-17'}), [])
 
+    def testFilteringRangeMonths(self):
+        ae, filt = self.filteringSetup()
+        for month in range(1, 13):
+            for n in range(1, month+1):
+                i = self.db.issue.create(title='%d.%d'%(month, n),
+                    deadline=date.Date('2001-%02d-%02d.00:00'%(month, n)))
+        self.db.commit()
+
+        for month in range(1, 13):
+            r = filt(None, dict(deadline='2001-%02d'%month))
+            assert len(r) == month, 'month %d != length %d'%(month, len(r))
+
     def testFilteringRangeInterval(self):
         ae, filt = self.filteringSetup()
         ae(filt(None, {'foo': 'from 0:50 to 2:00'}), ['1'])
@@ -2044,12 +2054,15 @@ class ClassicInitTest(unittest.TestCase):
 
         # check the basics of the schema and initial data set
         l = db.priority.list()
+        l.sort()
         ae(l, ['1', '2', '3', '4', '5'])
         l = db.status.list()
+        l.sort()
         ae(l, ['1', '2', '3', '4', '5', '6', '7', '8'])
         l = db.keyword.list()
         ae(l, [])
         l = db.user.list()
+        l.sort()
         ae(l, ['1', '2'])
         l = db.msg.list()
         ae(l, [])
