@@ -21,10 +21,14 @@ from __future__ import nested_scopes
 import unittest
 import time
 import datetime
+import calendar
+
+from roundup.date import Date, Interval, Range, fixTimeOverflow, \
+    get_timezone
 
-from roundup.date import Date, Interval, Range, fixTimeOverflow, get_timezone
 
 class DateTestCase(unittest.TestCase):
+
     def testDateInterval(self):
         ae = self.assertEqual
         date = Date("2000-06-26.00:34:02 + 2d")
@@ -358,6 +362,7 @@ class DateTestCase(unittest.TestCase):
         ae(str(Date('2003-1-1.23:00', add_granularity=1)), '2003-01-01.23:00:59')
         ae(str(Date('2003', add_granularity=1)), '2003-12-31.23:59:59')
         ae(str(Date('2003-5', add_granularity=1)), '2003-05-31.23:59:59')
+        ae(str(Date('2003-12', add_granularity=1)), '2003-12-31.23:59:59')
         ae(str(Interval('+1w', add_granularity=1)), '+ 14d')
         ae(str(Interval('-2m 3w', add_granularity=1)), '- 2m 14d')
 
@@ -466,9 +471,25 @@ class TimezoneTestCase(unittest.TestCase):
         date = Date(date, tz)
         ae(str(date), '2006-01-01.11:00:00')
 
+
+class RangeTestCase(unittest.TestCase):
+
+    def testRange(self):
+        ae = self.assertEqual
+        r = Range('2006', Date)
+        ae(str(r.from_value), '2006-01-01.00:00:00')
+        ae(str(r.to_value), '2006-12-31.23:59:59')
+        for i in range(1, 13):
+            r = Range('2006-%02d'%i, Date)
+            ae(str(r.from_value), '2006-%02d-01.00:00:00'%i)
+            ae(str(r.to_value), '2006-%02d-%02d.23:59:59'%(i,
+                calendar.mdays[i]))
+
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(DateTestCase))
+    suite.addTest(unittest.makeSuite(RangeTestCase))
     try:
         import pytz
     except ImportError:
