@@ -13,7 +13,7 @@ from roundup import instance
 # open the instance
 if len(sys.argv) < 2:
     print "Error: Not enough arguments"
-    print __doc__.strip()%(sys.argv[0], username)
+    print __doc__.strip()%(sys.argv[0])
     sys.exit(1)
 tracker_home = sys.argv[1]
 N = int(sys.argv[2])
